@@ -10,7 +10,7 @@ use App::Sqitch::X qw(hurl);
 use Hash::Merge 'merge';
 use Mouse;
 
-our $VERSION = '0.982';
+our $VERSION = '0.983';
 
 has sqitch => (
     is       => 'ro',
@@ -57,6 +57,7 @@ sub command {
 
 sub load {
     my ( $class, $p ) = @_;
+    my $sqitch = $p->{sqitch};
 
     # We should have a command.
     $class->usage unless $p->{command};
@@ -68,9 +69,8 @@ sub load {
         eval "require $pkg" or die $@;
     }
     catch {
-
-        # Just die if something choked.
-        die $_ unless /^Can't locate/;
+        # Emit the original error for debugging.
+        $sqitch->debug($_);
 
         # Suggest help if it's not a valid command.
         hurl {
@@ -90,7 +90,7 @@ sub load {
     );
 
     # Instantiate and return the command.
-    $params->{sqitch} = $p->{sqitch};
+    $params->{sqitch} = $sqitch;
     return $pkg->new($params);
 }
 
