@@ -10,7 +10,7 @@ use namespace::autoclean;
 
 extends 'App::Sqitch::Command';
 
-our $VERSION = '0.982';
+our $VERSION = '0.983';
 
 has note => (
     is       => 'ro',
@@ -21,7 +21,7 @@ has note => (
 
 sub options {
     return qw(
-        note|n=s@
+        note|n|m=s@
     );
 }
 
