@@ -17,7 +17,7 @@ extends 'App::Sqitch::Engine';
 sub dbh; # required by DBIEngine;
 with 'App::Sqitch::Role::DBIEngine';
 
-our $VERSION = '0.982';
+our $VERSION = '0.983';
 
 has client => (
     is       => 'ro',
@@ -358,7 +358,8 @@ sub _cid {
         }, undef, $project || $self->plan->project)->[0];
     } catch {
         # MySQL error code 1049 (ER_BAD_DB_ERROR): Unknown database '%-.192s'
-        return if $DBI::err == 1049;
+        # MySQL error code 1146 (ER_NO_SUCH_TABLE): Table '%s.%s' doesn't exist
+        return if $DBI::err && ($DBI::err == 1049 || $DBI::err == 1146);
         die $_;
     };
 }
